@@ -1,7 +1,7 @@
 #! /usr/bin/env perl
 # PODNAME: kamstrup-kem-split.pl
 # ABSTRACT: Split encrypted KEM file input from the Kamstrup backend into separate XML files with device information
-our $VERSION = '0.003'; # VERSION	
+our $VERSION = '0.004'; # VERSION	
 
 use Modern::Perl '2022';
 use App::KamstrupKemSplit;
@@ -22,6 +22,9 @@ GetOptions(
 	'key=s'     => \$key,
 	'config=s'  => \$config
 ) or pod2usage(2);
+
+pod2usage(1) if (defined $help || !defined $ARGV[0]);
+
 if ($verbose) {
 	Log::Log4perl->easy_init($DEBUG);
 	INFO "Starting in verbose mode";
@@ -29,6 +32,7 @@ if ($verbose) {
 	Log::Log4perl->easy_init($INFO);
 }
 
+
 # Open the config file
 my $orders;
 $orders = read_config($config) if (defined $config);
@@ -86,7 +90,7 @@ kamstrup-kem-split - Splits an encrypted delivery file from Kamstrup into separa
 
 =head1 SYNOPSIS
 
-    ./kamstrup-kem-split.pl --key=<key> [--config=<configfile>] C<inputfile_from_backend>
+    ./kamstrup-kem-split.pl --key=<key> [--config=<configfile>] inputfile_from_backend
 
 =head1 DESCRIPTION
 
